#!/usr/bin/env node
/*!
 * gitmars v3.3.5
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const sh = require("shelljs");
const { green, yellow } = require("chalk");
const inquirer = require("inquirer");
const getGitRevParse = require("@gitmars/core/lib/git/getGitRevParse");
const getIsGitProject = require("@gitmars/core/lib/git/getIsGitProject");
const { removeFile } = require("@gitmars/core/lib/utils/file");
const { createArgs } = require("@gitmars/core/lib/utils/command");
const { cleanCache } = require("@gitmars/core/lib/cache/cache");
const { cleanPkgInfo } = require("@gitmars/core/lib/utils/pkgInfo");
const { cleanBuildConfig } = require("@gitmars/core/lib/build/buildConfig");
const { options, args } = require("./conf/clean");
const { gitDir } = getGitRevParse();
sh.config.silent = true;
program.name("gitm clean").usage("[-f --force]").description("\u6E05\u7406gitmars\u7F13\u5B58");
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (opt) => {
  if (getIsGitProject()) {
    if (opt.force) {
      await inquirer.prompt({
        type: "confirm",
        name: "value",
        message: "\u60A8\u8F93\u5165\u4E86--force\uFF0C\u5C06\u540C\u65F6\u6E05\u7406gitmars\u6267\u884C\u7F13\u5B58\u3002\u662F\u5426\u7EE7\u7EED\uFF1F",
        default: false
      }).then((answers) => {
        if (!answers.value) {
          sh.echo(green("\u5DF2\u9000\u51FA"));
          process.exit(0);
        }
      });
      removeFile([
        {
          name: "gitmars\u6307\u4EE4\u961F\u5217\u7F13\u5B58\u6587\u4EF6",
          url: gitDir + "/.gitmarscommands"
        },
        {
          name: "gitmars\u6267\u884C\u65E5\u5FD7\u6587\u4EF6",
          url: gitDir + "/.gitmarslog"
        }
      ]);
    }
  } else {
    sh.echo(yellow("\u5F53\u524D\u76EE\u5F55\u4E0D\u662Fgit\u9879\u76EE\u76EE\u5F55"));
  }
  cleanBuildConfig();
  cleanPkgInfo();
  cleanCache();
});
program.parse(process.argv);
