#!/usr/bin/env node
/*!
 * gitmars v3.3.5
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const sh = require("shelljs");
const { green, red } = require("chalk");
const getBranchesFromID = require("@gitmars/core/lib/git/getBranchesFromID");
const getIsGitProject = require("@gitmars/core/lib/git/getIsGitProject");
const getCurrentBranch = require("@gitmars/core/lib/git/getCurrentBranch");
const getIsMergedTargetBranch = require("@gitmars/core/lib/git/getIsMergedTargetBranch");
const getIsUpdatedInTime = require("@gitmars/core/lib/git/getIsUpdatedInTime");
const getIsMergeAction = require("@gitmars/core/lib/git/getIsMergeAction");
const getBehindLogs = require("@gitmars/core/lib/git/getBehindLogs");
const { createArgs } = require("@gitmars/core/lib/utils/command");
const { init, remove } = require("@gitmars/core/lib/hook/index");
if (!getIsGitProject()) {
  sh.echo(red("\u5F53\u524D\u76EE\u5F55\u4E0D\u662Fgit\u9879\u76EE\u76EE\u5F55"));
  process.exit(1);
}
const getConfig = require("@gitmars/core/lib/getConfig");
const { options, args } = require("./conf/hook");
const config = getConfig();
program.name("gitm hook").usage(
  "[command] [args...] [--no-verify] [--lastet [lastet]] [--limit [limit]] [-t --type <type>] [--branch [branch]]"
).description("git hook\u94A9\u5B50");
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(
  async (command, args2, opt) => {
    console.log("gitmars hooks is running");
    if (opt.noVerify) {
      process.exit(0);
      return;
    }
    if (command === "init") {
      init();
    } else if (command === "remove") {
      remove();
    } else {
      const types = opt.type ? opt.type.split(",") : [];
      const mainBranches = [
        config.master,
        config.develop,
        config.release,
        config.support,
        config.bugfix
      ];
      const current = getCurrentBranch();
      console.log(
        types,
        process.env,
        process.argv,
        getBranchesFromID("2080d17e")
      );
      if (current !== config.develop && mainBranches.includes(current) && types.includes("1")) {
        const [command2, branch] = process.env.GIT_REFLOG_ACTION ? process.env.GIT_REFLOG_ACTION.split(" ") : [];
        if (command2 === "merge") {
          const isMergedBranch = getIsMergedTargetBranch(
            branch,
            config.develop,
            true
          );
          if (!isMergedBranch) {
            console.info(
              red("\u68C0\u6D4B\u5230\u4F60\u7684\u5206\u652F\u6CA1\u6709\u5408\u5E76\u8FC7" + config.develop)
            );
            process.exit(0);
          } else {
            console.info(green(branch + "\u5408\u5E76\u8FC7" + config.develop));
          }
        }
      }
      if (mainBranches.includes(current) && types.includes("2")) {
        const [command2, branch] = process.env.GIT_REFLOG_ACTION ? process.env.GIT_REFLOG_ACTION.split(" ") : [];
        const branchPrefix = branch.split("/")[0];
        if (command2 === "merge") {
          const isUpdatedInTime = getIsUpdatedInTime({
            lastet: opt.lastet,
            branch
          });
          if (!isUpdatedInTime) {
            console.info(
              red(
                "\u68C0\u6D4B\u5230\u4F601\u5468\u5185\u6CA1\u6709\u540C\u6B65\u8FC7\u4E3B\u5E72" + branchPrefix + "\u5206\u652F\u4EE3\u7801"
              )
            );
            process.exit(0);
          } else {
            console.info(green(branch + "\u4E00\u5468\u5185\u540C\u6B65\u8FC7\u4E3B\u5E72\u5206\u652F\u4EE3\u7801"));
          }
        }
      }
      if (mainBranches.includes(current) && types.includes("3")) {
        const isMergeAction = getIsMergeAction();
        if (!isMergeAction) {
          console.info(red("\u68C0\u6D4B\u5230\u4F60\u76F4\u63A5\u5728\u4E3B\u5E72\u5206\u652F\u4FEE\u6539\u4EE3\u7801"));
          process.exit(0);
        } else {
          console.info(green("\u6700\u540E\u4E00\u6761\u8BB0\u5F55\u662Fmerge\u8BB0\u5F55"));
        }
      }
      if (mainBranches.includes(current) && types.includes("4")) {
        const behindLogs = getBehindLogs();
        if (!behindLogs.length) {
          console.info("\u4F60\u672C\u5730\u5206\u652F\u7248\u672C\u843D\u540E\u4E8E\u8FDC\u7A0B\u5206\u652F\uFF0C\u8BF7\u5148\u6267\u884Cpull");
          process.exit(0);
        } else {
          console.info(green("\u672C\u5730\u7248\u672C\u6CA1\u6709\u843D\u540E\u8FDC\u7A0B\uFF0C\u53EF\u76F4\u63A5push"));
        }
      }
    }
    process.exit(0);
  }
);
program.parse(process.argv);
