#!/usr/bin/env node
/*!
 * gitmars v3.3.5
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const ora = require("ora");
const { red, green } = require("chalk");
const { createArgs } = require("@gitmars/core/lib/utils/command");
const { spawnSync } = require("@gitmars/core/lib/spawn");
const echo = require("@gitmars/core/lib/utils/echo");
const { options, args } = require("./conf/install");
program.name("gitm install").usage(
  "<pluginName> [version] [-m --mirror] [-c --client [client]] [-r --registry <registry>]"
).description("\u5B89\u88C5\u63D2\u4EF6\uFF0C\u4F8B\u5982\uFF1A@gitmars/ui");
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(
  (pluginName, version, opt) => {
    if (!pluginName) {
      echo(red("\u8BF7\u8F93\u5165\u63D2\u4EF6\u540D\u79F0"));
      process.exit(1);
    }
    const spinner = ora();
    if (version) {
      const match = version.match(/[0-9.]+$/);
      if (match)
        version = match[0];
      else if (![
        "alpha",
        "lite",
        "beta",
        "release",
        "latest",
        "next"
      ].includes(version)) {
        console.error(
          "\u8F93\u5165\u7684\u7248\u672C\u53F7\u4E0D\u6B63\u786E\uFF0C\u4EC5\u652F\u6301\uFF1Aalpha\u3001lite\u3001beta\u3001release\u3001latest\u3001next"
        );
        process.exit(0);
      }
    } else {
      version = "latest";
    }
    let cmdAdd;
    switch (opt.client) {
      case "yarn":
        cmdAdd = [
          opt.client,
          ["global", "add", `${pluginName}@${version}`]
        ];
        break;
      case "pnpm":
        cmdAdd = [opt.client, ["add", "-g", `${pluginName}@${version}`]];
        break;
      default:
        cmdAdd = [
          opt.client,
          ["install", "-g", `${pluginName}@${version}`]
        ];
        break;
    }
    if (!opt.registry && opt.mirror) {
      opt.registry = "https://registry.npmmirror.com";
    }
    if (opt.registry) {
      cmdAdd[1] = cmdAdd[1].concat(["-registry", opt.registry]);
    }
    spinner.start(green("\u6B63\u5728\u5B89\u88C5"));
    const install = spawnSync(...cmdAdd, {
      stdio: "ignore",
      shell: process.platform === "win32"
    });
    if (install.status === 0) {
      spinner.succeed(green("\u5B89\u88C5\u5B8C\u6210"));
    } else {
      spinner.fail(red("\u5B89\u88C5\u51FA\u9519\u4E86\uFF0C\u8BF7\u8054\u7CFB\u7BA1\u7406\u5458"));
    }
    spinner.stop();
    process.exit(0);
  }
);
program.parse(process.argv);
